
Denial-of-service by locking out accounts
-------

**Description:**

whenever there is offered the opportunity to log into the application it should not lock 
out accounts. A hacker could abuse this function to make the application deny access 
towards its power users.


**Solution:**

The application should not lock-out users when they enter false login credentials.
	